# OASYS2-SHADOW4

This is the official user interface for SHADOW4 (https://github.com/oasys-kit/shadow4). It is presented as an OASYS 2.0 add-on.

## OASYS2-shadow4 installation as user

To install the add-on as user: 

+ In the Oasys window, open "Options->Add-ons..."
+ Check the options "Shadow4" and "Shadow4 Avdanced". Click "OK"
+ Restart Oasys.


## beta tests
A collection of workspaces are being created containing parallel branches of simulations with shadow3 and shadow4. They are in the repository https://github.com/oasys-kit/shadow4workspaces

Please report issues in https://github.com/oasys-kit/shadow4/issues


